<?php
/**
 * Admin notices.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'ATCP_Admin_Notices' ) ) {
	/**
	 * Admin notices class.
	 *
	 * @since 1.0.0
	 */
	class ATCP_Admin_Notices {

		/**
		 * Class init.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {
			add_action( 'admin_init', array( $this, 'dismiss_new_installation_notice' ) );
			add_action( 'admin_notices', array( $this, 'new_installation_notice' ) );
		}

		/**
		 * First time plugin installation message.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function new_installation_notice() {
			if ( 'yes' === get_option( 'atcp_dismiss_plugin_installed_notice' ) ) {
				return;
			}

			require_once ATCP_PLUGIN_PATH . 'includes/admin/notices/installation-notice.php';
		}

		/**
		 * Dismiss first time plugin installation message.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function dismiss_new_installation_notice() {
			if ( ! isset( $_GET['atcp_action'] ) || 'dismiss_plugin_installed_notice' !== $_GET['atcp_action'] || ! isset( $_GET['_wpnonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_GET['_wpnonce'] ) ) ) ) {
				return;
			}

			update_option( 'atcp_dismiss_plugin_installed_notice', 'yes' );
			wp_safe_redirect( admin_url( '/admin.php?page=woocommerce-added-to-cart-popup' ) );
		}

	}

	return new ATCP_Admin_Notices();
}
