<?php
/**
 * Plugin admin main settings page.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;
?>

<div class="wrap">

	<h1 class="atcp-admin-title">
		<?php esc_html_e( 'WooCommerce Added To Cart Popup', 'woo-atcp' ); ?>
		<small><a href="https://wecreativez.com/" target="_blank"><?php esc_html_e( 'By WeCreativez', 'woo-atcp' ); ?></a></small>
	</h1>

	<?php settings_errors(); ?>

	<?php
		$active_tab = isset( $_GET['tab'] ) ? sanitize_key( $_GET['tab'] ) : 'appearance_settings'; // phpcs:ignore WordPress.Security.NonceVerification.Recommended

		// phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
		$tabs = array(
			'appearance_settings' => array(
				'label'   => __( 'Appearance', 'woo-atcp' ),
				'display' => true,
			),
			'popup_settings'      => array(
				'label'   => __( 'Popup Settings', 'woo-atcp' ),
				'display' => true,
			),
			'suggested_products'  => array(
				'label'   => __( 'Suggested Products', 'woo-atcp' ),
				'display' => true,
			),
			'shortcodes'          => array(
				'label'   => __( 'Shortcodes', 'woo-atcp' ),
				'display' => false,
			),
		);

		/**
		 * Filter tabs.
		 *
		 * @since 1.0.0
		 */
		apply_filters( 'atcp_admin_setting_tabs', $tabs );
		?>

	<h2 class="nav-tab-wrapper">

		<?php foreach ( $tabs as $tab_id => $tab ) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited ?>

			<?php if ( isset( $tab['display'] ) && true === $tab['display'] ) : ?>

				<a href="?page=woocommerce-added-to-cart-popup&tab=<?php echo esc_attr( $tab_id ); ?>" id="<?php echo esc_attr( $tab_id ); ?>" class="nav-tab <?php echo $tab_id === $active_tab ? 'nav-tab-active' : ''; ?>">
					<?php echo esc_html( $tab['label'] ); ?>
				</a>

			<?php endif; ?>

		<?php endforeach; ?>

	</h2>

	<form class="act-admin-form" method="POST" action="options.php">

		<?php
		if ( 'popup_settings' === $active_tab ) {

			ATCP_Settings::do_settings( 'atcp_popup_settings' );
			submit_button();

		} elseif ( 'suggested_products' === $active_tab ) {

			ATCP_Settings::do_settings( 'atcp_suggested_products_settings' );
			submit_button();

		} elseif ( 'shortcodes' === $active_tab ) {

			require_once ATCP_PLUGIN_PATH . 'includes/admin/views/atcp-admin-shortcodes-page.php';

		} else {

			ATCP_Settings::do_settings( 'atcp_appearance_settings' );
			submit_button();

		}

		?>

	</form>

</div>
