<?php
/**
 * Plugin enqueue scripts.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'ATCP_Enqueue' ) ) {

	/**
	 * Frontend enqueue scripts class.
	 *
	 * @since 1.0.0
	 */
	class ATCP_Enqueue {

		/**
		 * Class constructor.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ), 30 );
		}

		/**
		 * Enqueue scripts, styles, and embed scripts.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function enqueue_scripts() {
			/**
			 * Suffix.
			 */
			$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

			if ( atpc_is_hide_on_current_page() ) {
				return;
			}

			wp_enqueue_style( 'atcp-style', ATCP_PLUGIN_URL . 'assets/css/atcp-style' . $suffix . '.css', '', ATCP_PLUGIN_VER );
			wp_enqueue_script( 'atcp-script', ATCP_PLUGIN_URL . 'assets/js/atcp-script' . $suffix . '.js', array( 'jquery' ), ATCP_PLUGIN_VER, true );
			wp_localize_script(
				'atcp-script',
				'wcAtcpObject',
				array(
					'ajax_url'        => admin_url( 'admin-ajax.php' ),
					'wc_ajax_url'     => WC_AJAX::get_endpoint( '%%endpoint%%' ),
					'security_token'  => wp_create_nonce( 'atcp_security_nonce' ),
					'is_vibration_on' => 'yes' === get_option( 'atcp_vibrate_on_add_to_cart' ) ? true : false,
					'is_auto_hide'    => 'yes' === get_option( 'atcp_hide_popup_automatically' ) ? true : false,
					'auto_hide_time'  => get_option( 'atcp_hide_popup_automatically_after' ),
					'version'         => ATCP_PLUGIN_VER,
				)
			);

			$css = '.wc-atcp {
				--atcp-primary-bg-color: ' . esc_html( get_option( 'atcp_primary_background_color' ) ) . ';
				--atcp-primary-text-color: ' . esc_html( get_option( 'atcp_primary_text_color' ) ) . ';
				--atcp-secondary-bg-color: ' . esc_html( get_option( 'atcp_secondary_background_color' ) ) . ';
				--atcp-secondary-text-color: ' . esc_html( get_option( 'atcp_secondary_text_color' ) ) . ';
			}';

			if ( 'yes' !== get_option( 'atcp_hide_popup_overlay' ) ) {
				$css .= '.wc-atcp {
					background-color: rgba(0, 0, 0, 0.4);
				}';
			}

			// Custom CSS.
			$css .= wp_kses_post( get_option( 'atcp_custom_css' ) );

			wp_add_inline_style( 'atcp-style', $css );

		}

	}

	global $atcp_enqueue;

	$atcp_enqueue = new ATCP_Enqueue();
}
