<?php
/**
 * Cart popup template.
 *
 * @author  WeCreativez
 * @package WooCommerce Added to Cart Popup
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;
?>

<div class="wc-atcp-product">

	<?php if ( 'yes' !== get_option( 'atcp_hide_product_image' ) ) : ?>
		<div class="wc-atcp-product__col1">
			<div class="wc-atcp-product__image" style="background-image: url( <?php echo esc_url( $product_image ); ?> )"></div>
		</div>
	<?php endif; ?>

	<div class="wc-atcp-product__col2">

		<div class="wc-atcp-popup-notice">
			<?php echo ATCP_Icons::get( 'check-in-round' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?> <span><?php echo esc_html( get_option( 'atcp_addded_to_cart_message' ) ); ?></span>
		</div>

		<?php if ( 'yes' !== get_option( 'atcp_hide_product_title' ) ) : ?>
			<h3 class="wc-atcp-product__name"><?php echo $product_name; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></h3>
		<?php endif; ?>

		<?php if ( 'yes' !== get_option( 'atcp_hide_product_price' ) ) : ?>
			<div class="wc-atcp-product__price"><?php echo $product_price; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
		<?php endif; ?>

		<?php if ( 'yes' !== get_option( 'atcp_hide_quantity_buttons' ) ) : ?>

			<div class="wc-atcp-product__qty">
				<div class="wc-atcp-product__qty-minus"><?php echo ATCP_Icons::get( 'minus' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>

				<?php
				if ( $_product->is_sold_individually() ) {
					$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
				} else {
					$product_quantity = atcp_woocommerce_quantity_input(
						array(
							'input_name'   => $cart_item_key,
							'input_value'  => $cart_item['quantity'],
							'max_value'    => $_product->get_max_purchase_quantity(),
							'min_value'    => '1',
							'product_name' => $_product->get_name(),
							'class',
						),
						$_product,
						false
					);
				}

					echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				?>

				<div class="wc-atcp-product__qty-plus"><?php echo ATCP_Icons::get( 'plus' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
			</div>

		<?php endif; ?>

		<div class="wc-atcp-cart">

			<?php if ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) && 'yes' !== get_option( 'atcp_hide_cart_shipping_total' ) ) : ?>
				<?php $chosen_shipping_method_price = WC()->session->get( 'cart_totals' ); ?>
				<?php $chosen_shipping_method_price = isset( $chosen_shipping_method_price['shipping_total'] ) ? $chosen_shipping_method_price['shipping_total'] : false; ?>
				<?php if ( $chosen_shipping_method_price ) : ?>
					<div class="wc-atcp-cart__row">
						<div class="wc-atcp-cart__label"><?php echo esc_html( get_option( 'atcp_cart_shipping_text' ) ); ?></div>
						<div id="wc-atcp-cart-shipping" class="wc-atcp-cart__value"><?php echo wc_price( $chosen_shipping_method_price ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
					</div>
				<?php endif; ?>
			<?php endif; ?>

			<?php if ( 'yes' !== get_option( 'atcp_hide_cart_total' ) ) : ?>
				<div class="wc-atcp-cart__row">
					<div class="wc-atcp-cart__label"><?php echo esc_html( get_option( 'atcp_cart_total_text' ) ); ?></div>
					<div id="wc-atcp-cart-total" class="wc-atcp-cart__value"><?php echo wc_price( $cart_total ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
				</div>
			<?php endif; ?>

		</div>

		<div class="wc-atcp-cart__cta">

			<?php echo atcp_call_to_actions(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

		</div>

		<?php
		/**
		 * Hook: After cart call to action buttons.
		 *
		 * @since 1.0.3
		 *
		 * @param WC_Product $_product Product object.
		 */
		do_action( 'atcp_after_cart_cta', $_product );
		?>

	</div>

</div><!-- Product -->

<?php if ( 'yes' === get_option( 'atcp_suggested_products_status' ) ) : ?>

	<div class="wc-atcp-suggested-products">

	<?php
	/**
	 * Hook: Before suggested products.
	 *
	 * @since 1.0.0
	 *
	 * @param int $product_id
	 * @param int $_product WC_Product
	 */
	do_action( 'atcp_before_suggested_products', $_product->get_id(), $_product );

	echo do_shortcode( get_option( 'atcp_suggested_products_content' ) );

	/**
	 * Hook: After suggested products.
	 *
	 * @since 1.0.0
	 *
	 * @param int $product_id
	 * @param int $_product WC_Product
	 */
	do_action( 'atcp_after_suggested_products', $_product->get_id(), $_product );
	?>

	</div>

<?php endif; ?>
